{% extends "helpdesk/base.html" %}{% load i18n %}

{% block helpdesk_title %}{% trans "Delete Ticket" %}{% endblock %}

{% block helpdesk_body %}{% blocktrans with ticket.title as ticket_title %}
<h2>Delete Ticket</h2>

<p>Are you sure you want to delete this ticket (<em>{{ ticket_title }}</em>)? All traces of the ticket, including followups, attachments, and updates will be irreversably removed.</p>
{% endblocktrans %}

<p><a href='../'>{% trans "No, Don't Delete It" %}</a></p>

<form method='post' action='./'><input type='submit' value='{% trans "Yes - Delete It" %}' />{% csrf_token %}</form>
{% endblock %}
