<h1 style='font-family: "Trebuchet MS", Arial, sans-serif; font-size: 14pt; color: #6593C0'>{% block header %}Helpdesk{% endblock %}</h1>

{% block content %}{% endblock %}

<p style='font-family: "Trebuchet MS", Arial, sans-serif; font-size: 11pt;'>Beste Gr&uuml;&szlig;e,</p>

<p style='font-family: "Trebuchet MS", Arial, sans-serif; font-size: 11pt;'><b>{{ queue.title }}</b>{% if queue.email_address %}<br><a href='mailto:{{ queue.email_address }}'>{{ queue.email_address }}</a>{% endif %}</p>
    
<p style='font-family: "Trebuchet MS", Arial, sans-serif; font-size: 9pt; color: #808080;' color='#808080'>Diese E-Mail wurde, im Einklang mit unserer Privacy-Policy an Sie als Benutzer unseres Support-Dienstes gesendet. Bitte teilen Sie uns mit wenn Sie diese E-Mail nicht h&auml;tten bekommen sollen.</p>
